//    This file is part of Motion Watch.

//    Motion Watch is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    Motion Watch is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "logger.h"

void recLog(const string &line, shared_t *share)
{
    share->recLogLines.push_back(genTimeStr("[%Y-%m-%d-%H-%M-%S] ") + line + "<br>\n");
}

void detLog(const string &line, shared_t *share)
{
    share->detLogLines.push_back(genTimeStr("[%Y-%m-%d-%H-%M-%S] ") + line + "<br>\n");
}

void enforceMaxLogLines(vector<string> &log, shared_t *share)
{
    while (log.size() > share->maxLogLines)
    {
        log.erase(log.begin());
    }
}

string combine(const vector<string> &log)
{
    string ret;

    for (auto &&line : log) ret += line;

    return ret;
}

void logLoop(shared_t *share)
{
    string htmlText = "<!DOCTYPE html>\n";

    htmlText += "<html>\n";
    htmlText += "<head>\n";
    htmlText += "<link rel='stylesheet' href='/theme.css'>\n";
    htmlText += "</head>\n";
    htmlText += "<body>\n";
    htmlText += "<p>\n";

    while (share->logRun && (share->retCode == 0))
    {
        sleep(10);

        enforceMaxLogLines(share->recLogLines, share);
        enforceMaxLogLines(share->detLogLines, share);

        auto recLogFilePath = cleanDir(share->outDir) + "/recording_log.html";
        auto detLogFilePath = cleanDir(share->outDir) + "/detection_log.html";

        ofstream recFile(recLogFilePath.c_str());
        ofstream detFile(detLogFilePath.c_str());

        recFile << htmlText << combine(share->recLogLines) << "</p>\n</body>\n</html>";
        detFile << htmlText << combine(share->detLogLines) << "</p>\n</body>\n</html>";

        recFile.close();
        detFile.close();
    }
}
